@@ -2,10 +2,7 @@
 //! `syn::ItemTrait` definitions.
 use crate::proc_macro;
 use proc_macro2;
-use quote::{
-    quote,
-    ToTokens
-};
+use quote::{quote, ToTokens};
 use syn;
 use syn::spanned::Spanned;
 
@@ -19,14 +16,19 @@ const FIELDNAME: &str = "inner";
 
 /// Implements the specified trait for the given enum definition, assuming the trait definition is
 /// already present in local storage.
-pub fn add_enum_impls(enum_def: EnumDispatchItem, traitdef: syn::ItemTrait) -> proc_macro2::TokenStream {
+pub fn add_enum_impls(
+    enum_def: EnumDispatchItem,
+    traitdef: syn::ItemTrait,
+) -> proc_macro2::TokenStream {
     let traitname = traitdef.ident;
     let traitfns = traitdef.items;
 
-    let (impl_generics, ty_generics, where_clause) = traitdef.generics.split_for_impl();
+    let generics = if traitdef.generics.lt_token.is_some() { &traitdef.generics } else { &enum_def.generics };
+    let (_, enum_ty, _) = &traitdef.generics.split_for_impl();
+    let (impl_generics, ty_generics, where_clause) = generics.split_for_impl();
     let enumname = &enum_def.ident.to_owned();
     let trait_impl = quote! {
-        impl #impl_generics #traitname #ty_generics for #enumname #ty_generics #where_clause {
+        impl #impl_generics #traitname #enum_ty for #enumname #ty_generics #where_clause {
 
         }
     };
@@ -42,7 +44,7 @@ pub fn add_enum_impls(enum_def: EnumDispatchItem, traitdef: syn::ItemTrait) -> p
             .push(create_trait_match(trait_fn, &enum_def.ident, &variants));
     }
 
-    let from_impls = generate_from_impls(&enum_def.ident, &variants, &trait_impl.generics);
+    let from_impls = generate_from_impls(&enum_def.ident, &variants, &generics);
 
     let mut impls = proc_macro2::TokenStream::new();
     for from_impl in from_impls.iter() {
